@@ -5,9 +5,9 @@
 ;; Author: Grant Rosson <https://github.com/localauthor>
 ;; Created: November 4, 2022
 ;; License: GPL-3.0-or-later
-;; Package-Version: 0.7
-;; Package-Revision: 599be69ae1c1
-;; Homepage: https://github.com/localauthor/zk
+;; Package-Version: 20250905.1921
+;; Package-Revision: a634b6ec7af4
+;; URL: https://github.com/localauthor/zk
 ;; Package-Requires: ((emacs "27.1")(zk "0.6")(zk-index "0.9"))
 
 ;; This program is free software; you can redistribute it and/or modify it
@@ -26,7 +26,7 @@
 ;;; Commentary:
 
 ;; ZK-Desktop: A place (or places) for collecting, grouping, arranging, and
-;; saving curated selections of notes (also in txhe form of clickable links).
+;; saving curated selections of notes (also in the form of clickable links).
 
 ;; To enable integration with Embark, include '(zk-desktop-setup-embark)' in
 ;; your init config.
@@ -254,9 +254,8 @@ To quickly change this setting, call `zk-desktop-add-toggle'."
               (beginning-of-line)
               (if new-title
                   (unless (string= title new-title)
-                    (progn
-                      (search-forward title end)
-                      (replace-match new-title)))
+                    (search-forward title end)
+                    (replace-match new-title))
                 (progn
                   (search-forward title end)
                   (replace-match (propertize title 'face 'error))))
@@ -294,7 +293,7 @@ To quickly change this setting, call `zk-desktop-add-toggle'."
                 (end-of-line)
                 (overlay-put (make-overlay (point) (point))
                              'before-string
-                             (propertize" <- ID NOT FOUND" 'font-lock-face 'error))))
+                             (propertize " <- ID NOT FOUND" 'font-lock-face 'error))))
             (end-of-line)))))))
 
 ;;; Utilities
@@ -343,7 +342,7 @@ on zk-id at point."
         (items
          (cond
           (arg (zk--formatted-string arg zk-index-format))
-          ((eq major-mode 'zk-index-mode)
+          ((derived-mode-p 'zk-index-mode)
            (if (use-region-p)
                (buffer-substring
                 (save-excursion
@@ -384,7 +383,7 @@ on zk-id at point."
       (unless (bound-and-true-p truncate-lines)
         (toggle-truncate-lines))
       (zk-desktop-mode))
-    (if (eq major-mode 'zk-index-mode)
+    (if (derived-mode-p 'zk-index-mode)
         (message "Sent to %s - press D to switch" buffer)
       (message "Sent to %s" buffer))))
 
